
package com.redxun.knowledge.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.redxun.common.annotation.ClassDefine;
import com.redxun.common.base.db.BaseService;
import com.redxun.common.base.entity.JsonPageResult;
import com.redxun.common.base.entity.JsonResult;
import com.redxun.common.base.entity.QueryData;
import com.redxun.common.base.search.QueryFilter;
import com.redxun.common.base.search.QueryFilterBuilder;
import com.redxun.common.utils.ExceptionUtil;
import com.redxun.knowledge.entity.dao.KnowledgeCategory;
import com.redxun.knowledge.entity.vo.KnowledgeCategoryAdminVo;
import com.redxun.knowledge.service.KnowledgeCategoryServiceImpl;
import com.redxun.web.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/api-knowledge/knowledge/knowledgeCategory")
@Api(tags = "业务--知识分类表")
@ClassDefine(title = "业务--知识分类表", alias = "KnowledgeCategoryController", path = "/api-knowledge/knowledge/knowledgeCategory", packages = "", packageName = "子系统名称")
public class KnowledgeCategoryController extends BaseController<KnowledgeCategory> {

    @Autowired
    KnowledgeCategoryServiceImpl knowledgeCategoryService;


    @Override
    public BaseService getBaseService() {
        return knowledgeCategoryService;
    }

    @Override
    public String getComment() {
        return "业务--知识分类表";
    }

    @ApiOperation("知识分类列表 (后台)")
    @ApiImplicitParam(name = "queryData", value = "查询条件")
    @PostMapping("findAllKnowledgeCategory")
    public JsonPageResult findAllKnowledgeCategory(@RequestBody QueryData queryData) {
        JsonPageResult jsonResult = JsonPageResult.getSuccess("返回数据成功!");
        try {
            QueryFilter filter = QueryFilterBuilder.createQueryFilter(queryData);
            IPage page = knowledgeCategoryService.findAllKnowledgeCategory(filter);
            this.handlePage(page);
            jsonResult.setPageData(page);
        } catch (Exception e) {
            jsonResult.setSuccess(false);
            this.logger.error(ExceptionUtil.getExceptionMessage(e));
            jsonResult.setMessage(ExceptionUtil.getExceptionMessage(e));
        }
        return jsonResult;
    }

    @ApiOperation("根据id查询(数据回显)")
    @GetMapping("findByCategoryId")
    public JsonResult findByCategoryId(@RequestParam("pkId") String pkId){
        JsonResult jsonResult = JsonResult.getSuccessResult("获取数据成功");
        KnowledgeCategoryAdminVo knowledgeCategoryAdminVo = knowledgeCategoryService.findByCategoryId(pkId);
        jsonResult.setData(knowledgeCategoryAdminVo);
        return jsonResult;
    }



    @ApiOperation("根据id查询其下级分类信息(懒加载)")
    @GetMapping("findAllByCategoryId/{categoryId}")
    public JsonResult findAllByCategoryId(@PathVariable(value = "categoryId",required = false) String categoryId){
        JsonResult jsonResult = JsonResult.getSuccessResult("获取数据成功");
        KnowledgeCategory knowledgeCategory = knowledgeCategoryService.findAllByCategoryId(categoryId);
        jsonResult.setData(knowledgeCategory);
        return jsonResult;
    }

    @ApiOperation("根据id查询其上级分类信息")
    @GetMapping("findAllParentByCategoryId/{categoryId}")
    public JsonResult  findAllParentByCategoryId(@PathVariable("categoryId") String categoryId){
        JsonResult jsonResult = JsonResult.getSuccessResult("获取数据成功");
        KnowledgeCategoryAdminVo knowledgeCategoryAdminVo = knowledgeCategoryService.findAllParentByCategoryId(categoryId);
        jsonResult.setData(knowledgeCategoryAdminVo);
        return jsonResult;
    }

}

