
package com.redxun.knowledge.controller;

import com.redxun.common.annotation.ClassDefine;
import com.redxun.common.base.db.BaseService;
import com.redxun.common.base.entity.JsonResult;
import com.redxun.knowledge.entity.dao.Knowledge;
import com.redxun.knowledge.entity.dto.knowledgeDto;
import com.redxun.knowledge.entity.vo.KnowledgeApprovalVo;
import com.redxun.knowledge.entity.vo.KnowledgeVo;
import com.redxun.knowledge.service.KnowledgeServiceImpl;
import com.redxun.web.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Slf4j
@RestController
@RequestMapping("/api-knowledge/knowledge")
@Api(tags = "业务--知识表")
@ClassDefine(title = "业务--知识表", alias = "KnowledgeController", path = "/knowledge/knowledge", packages = "", packageName = "子系统名称")
public class KnowledgeController extends BaseController<Knowledge> {

    @Autowired
    KnowledgeServiceImpl knowledgeService;


    @Override
    public BaseService getBaseService() {
        return knowledgeService;
    }

    @Override
    public String getComment() {
        return "业务--知识表";
    }

    @ApiOperation(value = "根据分类id查询全部维基知识", httpMethod = "GET")
    @GetMapping("/findAllWiki/{categoryId}")
    public JsonResult findAllWiki(@PathVariable("categoryId") String categoryId) {
        JsonResult jsonResult = JsonResult.getSuccessResult("返回数据成功!");
        List<Knowledge> wikiList = knowledgeService.findAllWiki(categoryId);
        jsonResult.setData(wikiList);
        return jsonResult;
    }

    @ApiOperation(value = "新增知识", httpMethod = "POST")
    @PostMapping("create")
    public JsonResult create(@Validated @RequestBody knowledgeDto knowledgeDto) {
        JsonResult jsonResult = JsonResult.getSuccessResult("新增知识成功！");
        String pkId = knowledgeService.create(knowledgeDto);
        jsonResult.setData(pkId);
        return jsonResult;
    }

    @ApiOperation(value = "知识详情", httpMethod = "GET")
    @GetMapping("info")
    public JsonResult info(@RequestParam(value = "pkId") String pkId) {
        JsonResult jsonResult = JsonResult.getSuccessResult("获取知识详情成功！");
        jsonResult.setData(knowledgeService.info(pkId));
        return jsonResult;
    }
}

